module Cryptoexchange::Exchanges
  module Aphelion
    module Services
      class Market < Cryptoexchange::Services::Market
        class << self
          def supports_individual_ticker_query?
            false
          end
        end

        def fetch
          output = super(ticker_url)
          adapt_all(output)
        end

        def ticker_url
          "#{Cryptoexchange::Exchanges::Aphelion::Market::API_URL}/ticker"
        end

        def adapt_all(output)
          output.map do |pair|
            target, base = pair[0].split('-')
            market_pair  = Cryptoexchange::Models::MarketPair.new(
              base:   base,
              target: target,
              market: Aphelion::Market::NAME
            )
            adapt(market_pair, pair[1])
          end
        end

        def adapt(market_pair, output)
          ticker           = Cryptoexchange::Models::Ticker.new
          ticker.base      = market_pair.base
          ticker.target    = market_pair.target
          ticker.market    = Aphelion::Market::NAME
          ticker.last      = NumericHelper.to_d(output['last'])
          ticker.change    = NumericHelper.to_d(output['change24hrPercent'])
          ticker.high      = NumericHelper.to_d(output['high24hr'])
          ticker.low       = NumericHelper.to_d(output['low24hr'])
          ticker.bid       = NumericHelper.to_d(output['bid'])
          ticker.ask       = NumericHelper.to_d(output['ask'])
          ticker.volume    = NumericHelper.to_d(output['quoteVolume']) # api returning quote as base.
          ticker.timestamp = nil
          ticker.payload   = output
          ticker
        end
      end
    end
  end
end
